summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatsettings.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit44af2b7aa26c61f2f059acc7a9726319cacaabcf (patch)
tree09c93f4a6fdef07c083e731d9f327850e83a6bf5 /kdirstat/kdirstatsettings.cpp
parentb8e1a56a901671dbd336c9bfd129dfb72a0cc41f (diff)
downloadkdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.tar.gz
kdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirstatsettings.cpp')
-rw-r--r--kdirstat/kdirstatsettings.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index 46a1aae..e33a515 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -37,7 +37,7 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
i18n( "Settings" ), // caption
Ok | Apply | Default | Cancel | Help, // buttonMask
Ok, // defaultButton
- 0, // tqparent
+ 0, // parent
0, // name
false ) // modal
, _mainWin( mainWin )
@@ -132,8 +132,8 @@ KSettingsDialog::slotHelp()
KSettingsPage::KSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent )
- : TQWidget( tqparent )
+ TQWidget * parent )
+ : TQWidget( parent )
{
connect( dialog, TQT_SIGNAL( aboutToShow ( void ) ),
this, TQT_SLOT ( setup ( void ) ) );
@@ -159,9 +159,9 @@ KSettingsPage::~KSettingsPage()
KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _treeView( mainWin->treeView() )
, _maxButtons( KDirStatSettingsMaxColorButton )
@@ -274,9 +274,9 @@ KTreeColorsPage::enableColors( int maxColors )
KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _currentCleanup( 0 )
{
@@ -425,8 +425,8 @@ KCleanupPage::storeProps( KCleanup * cleanup )
/*--------------------------------------------------------------------------*/
-KCleanupListBox::KCleanupListBox( TQWidget *tqparent )
- : TQListBox( tqparent )
+KCleanupListBox::KCleanupListBox( TQWidget *parent )
+ : TQListBox( parent )
{
_selection = 0;
@@ -517,9 +517,9 @@ KCleanupListBoxItem::updateTitle()
/*--------------------------------------------------------------------------*/
-KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * tqparent,
+KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
KDirStatApp * mainWin )
- : TQWidget( tqparent )
+ : TQWidget( parent )
, _mainWin( mainWin )
{
TQVBoxLayout *outerBox = new TQVBoxLayout( this, 0, 0 ); // border, spacing
@@ -700,9 +700,9 @@ KCleanupPropertiesPage::fields() const
KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
, _treeView( mainWin->treeView() )
{
@@ -793,14 +793,14 @@ KGeneralSettingsPage::checkEnabledState()
KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin )
- : KSettingsPage( dialog, tqparent )
+ : KSettingsPage( dialog, parent )
, _mainWin( mainWin )
{
// kdDebug() << k_funcinfo << endl;
- TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // tqparent, border, spacing
+ TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
TQVBox * vbox = new TQVBox( this );
vbox->setSpacing( dialog->spacingHint() );
@@ -890,7 +890,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
label = new TQLabel( i18n( "Minim&um Treemap Tile Size: " ), gridBox );
- _minTileSize = new TQSpinBox( 0, 30, 1, gridBox ); // min, max, step, tqparent
+ _minTileSize = new TQSpinBox( 0, 30, 1, gridBox ); // min, max, step, parent
label->setBuddy( _minTileSize );
grid->addWidget( label, 1, 0 );
@@ -1032,9 +1032,9 @@ KTreemapPage::readColorEntry( KConfig * config, const char * entryName, TQColor
void
-addHStretch( TQWidget * tqparent )
+addHStretch( TQWidget * parent )
{
- TQWidget * stretch = new TQWidget( tqparent );
+ TQWidget * stretch = new TQWidget( parent );
stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
TQSizePolicy::Minimum, // vert
1, // hstretch
@@ -1043,9 +1043,9 @@ addHStretch( TQWidget * tqparent )
void
-addVStretch( TQWidget * tqparent )
+addVStretch( TQWidget * parent )
{
- TQWidget * stretch = new TQWidget( tqparent );
+ TQWidget * stretch = new TQWidget( parent );
stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
TQSizePolicy::Expanding, // vert
0, // hstretch